"use strict";
Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.toRefReactive = toRefReactive;
exports.toRefsReactive = toRefsReactive;
var _vue = require("vue");
function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
    }
}
function _defineProperties(target, props) {
    for(var i = 0; i < props.length; i++){
        var descriptor = props[i];
        descriptor.enumerable = descriptor.enumerable || false;
        descriptor.configurable = true;
        if ("value" in descriptor) descriptor.writable = true;
        Object.defineProperty(target, descriptor.key, descriptor);
    }
}
function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    return Constructor;
}
var ReactiveRefObjectImpl = /*#__PURE__*/ function() {
    "use strict";
    function ReactiveRefObjectImpl(_object, _key, _defaultValue) {
        _classCallCheck(this, ReactiveRefObjectImpl);
        this._object = _object;
        this._key = _key;
        this._defaultValue = _defaultValue;
        this.__v_isRef = true;
    }
    _createClass(ReactiveRefObjectImpl, [
        {
            key: "value",
            get: function get() {
                var val = this._object.value[this._key];
                return val === undefined ? this._defaultValue : val;
            },
            set: function set(newVal) {
                this._object.value[this._key] = newVal;
            }
        }
    ]);
    return ReactiveRefObjectImpl;
}();
function toRefReactive(object, key, defaultValue) {
    var val = object.value[key];
    return (0, _vue).isRef(val) ? val : new ReactiveRefObjectImpl(object, key, defaultValue);
}
function toObjectRefs(object) {
    return (0, _vue).toRefs(toRefsReactive(object));
}
function toRefsReactive(ref) {
    var ret = (0, _vue).reactive(Array.isArray(ref.value) ? [] : {});
    for(var key in ref.value){
        ret[key] = toRefReactive(ref, key);
    }
    return ret;
} // const a = ref({ name: '1' })
 // const name = toRefReactive(a, 'name')
 // const { name: name1 } = toRefs(toRefsReactive(a))
 // const { name: name2 } = toObjectRefs(a)
 /**
 在Vue3中，由于使用reactive生成的对象不能被重新赋值，所以我们一般采用 `const objRef = ref(object)` 的方式来定义一个需要被重复赋值的对象，但是这样的定义会导致读取对象的属性变得繁琐，例如：
 ```ts
 const objRef = ref({ name: 'H', age: 1 })
 objRef.value.name // 'H'
 objRef.value.age  // 1
 ```
 我希望能通过 toRefsReactive 提供一个快捷读取的方式，并且它可以顺利的和toRefs相结合
 ```ts
 const objRef = ref({ name: 'H', age: 1 })
 const obj = toRefsReactive(objRef)
 const { name, age } = toRefs(toRefsReactive(name, age))
 obj.name // 'H'
 name.value // 'H'
 obj.age // 1
 age.value // 1
 ```
 * */ 
